@@ -355,6 +355,8 @@ def hook_matplotlib(finder, module):
     the same directory as the executable.
     """
     import ast
+    from pkg_resources._vendor.packaging import version as pkgversion
+
     import matplotlib
 
     mpl_data_path = matplotlib.get_data_path()
@@ -368,9 +370,14 @@ def hook_matplotlib(finder, module):
     # see issue #71 fof further details
     tree = ast.parse(module.__source__)
 
+    # matplotlib <=3.3.4 requires '_get_data_path' to be patched
+    # matplotlib >= 3.4.0 requires 'get_data_path' to be patched
+    mpl_version = pkgversion.parse(matplotlib.__version__)
+    node_to_be_patched = 'get_data_path' if mpl_version >= pkgversion.parse('3.4.0') else '_get_data_path'
+
     class ChangeDef(ast.NodeTransformer):
         def visit_FunctionDef(self, node: ast.FunctionDef):
-            if node.name == '_get_data_path':
+            if node.name == node_to_be_patched:
                 node.body = ast.parse('return os.path.join(os.path.dirname(sys.executable), "mpl-data")').body
             return node
 
@@ -578,6 +585,10 @@ def hook_pandas(finder, module):
         finder.import_hook("pandas._libs.tslibs.base")
         finder.recursion_depth_pandas = depth
 
+def hook_Cryptodome(finder, module):
+    """pycryptodomex distributes the same package as pycryptodome under a different package name"""
+    hook_Crypto(finder, module)
+
 def hook_Crypto(finder, module):
     """pycryptodome includes compiled libraries as if they were Python C extensions (as .pyd files).
     However, they are not, as they cannot be imported by Python. Hence, those files should be treated
@@ -589,28 +600,30 @@ def hook_Crypto(finder, module):
     for path in Path(crypto_path).rglob('*.pyd'):
         finder.add_libfile(str(path.relative_to(os.path.dirname(crypto_path))), path)
 
+    package_name = module.__name__
+
     # patch pycryptodome to look for its "pyd" files in the bundle directory
-    finder.add_bootcode("""
+    finder.add_bootcode(f"""
 def patch_Crypto():
     import os
     import sys
 
     try:
-        import Crypto.Util._file_system
+        import {package_name}.Util._file_system
     except ImportError:
         # the hook should not work for pycrypto
         return
 
     def override_filename(dir_comps, filename):
-        if dir_comps[0] != "Crypto":
-            raise ValueError("Only available for modules under 'Crypto'")
+        if dir_comps[0] != "{package_name}":
+            raise ValueError("Only available for modules under '{package_name}'")
 
         dir_comps = list(dir_comps[1:]) + [filename]
-        root_lib = os.path.join(os.path.dirname(sys.executable), 'Crypto')
+        root_lib = os.path.join(os.path.dirname(sys.executable), '{package_name}')
 
         return os.path.join(root_lib, *dir_comps)
 
-    Crypto.Util._file_system.pycryptodome_filename = override_filename
+    {package_name}.Util._file_system.pycryptodome_filename = override_filename
 
 patch_Crypto()
 del patch_Crypto
@@ -671,3 +684,11 @@ def hook__ssl(finder, module):
         for dll_path in glob.glob(os.path.join(sys.base_prefix, "DLLs", dll_search)):
             dll_name = os.path.basename(dll_path)
             finder.add_dll(dll_path)
+
+def hook_wx(finder, module):
+    """
+    Avoid `wxPyDeprecationWarning: wx.lib.pubsub has been deprecated` and
+    `RuntimeError: Should not import this directly, used by pubsub.core if applicable`
+    when importing the full wx package
+    """
+    finder.excludes.append("wx.lib.pubsub")
